<template>
  <div class="app-container">
    <el-form :model="queryParams" ref="queryForm" :inline="true" v-show="showSearch" label-width="68px">
      <el-form-item label="工程名称" prop="title">
        <el-input
          v-model="queryParams.title"
          placeholder="请输入工程名称"
          clearable
          size="small"
          @keyup.enter.native="handleQuery"
        />
      </el-form-item>

      <el-form-item>
        <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
        <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
      </el-form-item>
    </el-form>

    <el-row :gutter="10" class="mb8">
      <el-col :span="1.5">
        <el-button
          type="primary"
          plain
          icon="el-icon-plus"
          size="mini"
          @click="handleAdd"
          v-hasPermi="['third:build:add']"
        >新增</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="success"
          plain
          icon="el-icon-edit"
          size="mini"
          :disabled="single"
          @click="handleUpdate"
          v-hasPermi="['third:build:edit']"
        >修改</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="danger"
          plain
          icon="el-icon-delete"
          size="mini"
          :disabled="multiple"
          @click="handleDelete"
          v-hasPermi="['third:build:remove']"
        >删除</el-button>
      </el-col>
      <el-col :span="1.5">
        <el-button
          type="warning"
          plain
          icon="el-icon-download"
          size="mini"
		  :loading="exportLoading"
          @click="handleExport"
          v-hasPermi="['third:build:export']"
        >导出</el-button>
      </el-col>
      <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
    </el-row>

    <el-table v-loading="loading" :data="buildList" @selection-change="handleSelectionChange">
      <el-table-column type="selection" width="55" align="center" />
      <el-table-column label="工程名称" align="center" prop="title" :show-overflow-tooltip="true"/>
      <el-table-column label="申报单位" align="center" prop="company" :show-overflow-tooltip="true"/>
      <el-table-column label="联系人" align="center" prop="username" :show-overflow-tooltip="true"/>
      <el-table-column label="联系电话" align="center" prop="phone" :show-overflow-tooltip="true"/>
      <el-table-column label="详细地址" align="center" prop="address" :show-overflow-tooltip="true"/>
      <el-table-column label="开工日期" align="center" prop="startTime">
        <template slot-scope="scope">
          <span>{{ parseTime(scope.row.startTime, '{y}-{m}-{d}') }}</span>
        </template>
      </el-table-column>
      <el-table-column label="竣工日期" align="center" prop="endTime">
        <template slot-scope="scope">
          <span>{{ parseTime(scope.row.endTime, '{y}-{m}-{d}') }}</span>
        </template>
      </el-table-column>
      <el-table-column label="施工状态" align="center" prop="status">
        <template slot-scope="scope">
          <span v-if="scope.row.status == 0" style="color: red">进行中</span>
          <span v-else-if="scope.row.status == 1" style="color: green">已结束</span>
          <span v-else>-</span>
        </template>
      </el-table-column>
     <!-- <el-table-column label="备注" align="center" prop="remark" :show-overflow-tooltip="true">
        <template slot-scope="scope">
          <span v-if="scope.row.remark">{{ scope.row.remark }}</span>
          <span v-else>-</span>
        </template>
      </el-table-column>-->
      <el-table-column label="操作" align="center" class-name="small-padding fixed-width" width="200">
        <template slot-scope="scope">
          <el-button
            size="mini"
            type="text"
            @click="handleSupervise(scope.row)"
          >监护</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-document"
            @click="handleDetail(scope.row)"
          >详情</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-edit"
            @click="handleUpdate(scope.row)"
            v-hasPermi="['third:build:edit']"
          >修改</el-button>
          <el-button
            size="mini"
            type="text"
            icon="el-icon-delete"
            @click="handleDelete(scope.row)"
            v-hasPermi="['third:build:remove']"
          >删除</el-button>
          <el-button
            size="mini"
            type="text"
            @click="handleEnd(scope.row)"
            v-if="scope.row.status != 1"
            v-hasPermi="['third:build:end']"
          >结束</el-button>
        </template>
      </el-table-column>
    </el-table>

    <pagination
      v-show="total>0"
      :total="total"
      :page.sync="queryParams.pageNum"
      :limit.sync="queryParams.pageSize"
      @pagination="getList"
    />

    <!-- 添加或修改第三方施工对话框 -->
    <el-dialog :title="title" :visible.sync="open" width="900px" append-to-body destroy-on-close :close-on-click-modal="false">
      <el-form ref="form" :model="form" :rules="rules" label-width="100px">
        <el-row>
          <el-col :span="12">
            <el-form-item label="工程名称" prop="title">
              <el-input v-model="form.title" placeholder="请输入工程名称" />
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="申报单位" prop="company">
              <el-input v-model="form.company" placeholder="请输入申报单位" />
            </el-form-item>
          </el-col>
        </el-row>

        <el-row>
          <el-col :span="12">
            <el-form-item label="联系人" prop="username">
              <el-input v-model="form.username" placeholder="请输入联系人" />
            </el-form-item>
          </el-col>
          <el-col :span="12">
            <el-form-item label="联系电话" prop="phone">
              <el-input v-model="form.phone" placeholder="请输入联系电话" />
            </el-form-item>
          </el-col>
        </el-row>

        <el-row>
          <el-col :span="24">
            <el-form-item label="经纬度坐标" prop="longitude">
              <el-col :span="8">
                <el-input v-model="form.longitude" placeholder="请输入经度"/>
              </el-col>
              <el-col :span="8" style="margin-left: 20px">
                <el-input v-model="form.latitude" placeholder="请输入纬度"/>
              </el-col>
              <el-col :span="4" style="margin-left: 30px">
                <el-button type="primary" plain @click="MapdialogFun">选择经纬度</el-button>
              </el-col>
            </el-form-item>
          </el-col>
        </el-row>

        <el-row>
          <el-col :span="24">
            <el-form-item label="详细地址" prop="address">
              <el-input v-model="form.address" placeholder="请输入详细地址" />
            </el-form-item>
          </el-col>
        </el-row>

        <el-row>
          <el-col :span="12">
            <el-form-item label="开工日期" prop="startTime">
              <el-date-picker clearable size="small"
                              v-model="form.startTime"
                              type="date"
                              value-format="yyyy-MM-dd"
                              style="width: 100%"
                              placeholder="选择开工日期">
              </el-date-picker>
            </el-form-item>
          </el-col>

          <el-col :span="12">
            <el-form-item label="竣工日期" prop="endTime">
              <el-date-picker clearable size="small"
                              v-model="form.endTime"
                              type="date"
                              style="width: 100%"
                              value-format="yyyy-MM-dd"
                              placeholder="选择竣工日期">
              </el-date-picker>
            </el-form-item>
          </el-col>
        </el-row>

        <el-row>
          <el-form-item label="备注" prop="remark">
            <el-input type="textarea" v-model="form.remark" placeholder="请输入备注" />
          </el-form-item>
        </el-row>

        <el-row>
          <div class="picture-label">安全告知书图片</div>
          <MultipleImageUpload
            v-model="form.noticeUrl"
            ref="notice"
          />
        </el-row>

        <el-row>
          <div class="picture-label">管道安全保护协议图片</div>
          <MultipleImageUpload
            v-model="form.protectUrl"
            ref="protectUrl"
          />
        </el-row>

        <el-row>
          <div class="picture-label">监护协议图片</div>
          <MultipleImageUpload
            v-model="form.custodyUrl"
            ref="custodyUrl"
          />
        </el-row>


        <el-row>
          <div class="picture-label">管道现场安全技术交底图片</div>
          <MultipleImageUpload
            v-model="form.discloseUrl"
            ref="discloseUrl"
          />
        </el-row>

        <el-row>
          <div class="picture-label">施工验收图片</div>
          <MultipleImageUpload
            v-model="form.checkUrl"
            ref="checkUrl"
          />
        </el-row>

      </el-form>
      <div slot="footer" class="dialog-footer">
        <el-button type="primary" @click="submitForm">确 定</el-button>
        <el-button @click="cancel">取 消</el-button>
      </div>
    </el-dialog>

    <!-- 坐标选择 -->
    <GetPos
      :dialogVisible.sync="dialogTableVisibles"
      :devicePos="devicePos"
      @close="dialogcancelFun"
      @getPath="getPath"
      style="z-index: 3000"
    />

    <!-- 详情 -->
    <BuildDetail ref="buildDetail"/>

  </div>
</template>

<script>
import { listBuild, getBuild, delBuild, addBuild, updateBuild, exportBuild } from "@/api/thirdbuild/build";
import GetPos from '@/components/GetPos';
import MultipleImageUpload from "@/components/MultipleImageUpload";
import BuildDetail from "./components/BuildDetail";
export default {
  name: "Build",
  components: {
    GetPos,
    MultipleImageUpload,
    BuildDetail
  },
  data() {
    return {
      // 遮罩层
      loading: true,
      // 导出遮罩层
      exportLoading: false,
      // 选中数组
      ids: [],
      titles: [],
      // 非单个禁用
      single: true,
      // 非多个禁用
      multiple: true,
      // 显示搜索条件
      showSearch: true,
      // 总条数
      total: 0,
      // 第三方施工表格数据
      buildList: [],
      // 弹出层标题
      title: "",
      // 是否显示弹出层
      open: false,
      // 查询参数
      queryParams: {
        pageNum: 1,
        pageSize: 10,
        title: null,
        longitude: null,
        latitude: null,
        address: null,
        startTime: null,
        endTime: null,
        noticeUrl: null,
        protectUrl: null,
        custodyUrl: null,
        discloseUrl: null,
        checkUrl: null,
        status: null,
      },
      // 表单参数
      form: {},
      // 表单校验
      rules: {
        title: [
          { required: true, message: "工程名称不能为空", trigger: "blur" }
        ],
        company: [
          { required: true, message: "申报单位不能为空", trigger: "blur" }
        ],
        username: [
          { required: true, message: "联系人不能为空", trigger: "blur" }
        ],
        phone: [
          { required: true, message: "联系电话不能为空", trigger: "blur" },
          {
            type: 'number',
            message: '手机号格式不正确',
            trigger: 'blur',
            transform(value) {
              let phonereg = 11 && /^((13|14|15|16|17|18|19)[0-9]{1}\d{8})$/
              if (!phonereg.test(value)) {
                return false
              } else {
                return Number(value)
              }
            }
          }
        ],
        longitude: [
          { required: true, message: "经纬度不能为空", trigger: "blur" }
        ],
        address: [
          { required: true, message: "地址不能为空", trigger: "blur" }
        ],
        startTime: [
          { required: true, message: "请选择开工日期", trigger: "change" }
        ],
        endTime: [
          { required: true, message: "请选择竣工日期", trigger: "change" }
        ],
      },
      dialogTableVisibles: false,
      devicePos: []
    };
  },
  created() {
    this.getList();
  },
  methods: {
    /** 查询第三方施工列表 */
    getList() {
      this.loading = true;
      listBuild(this.queryParams).then(response => {
        this.buildList = response.rows;
        this.total = response.total;
        this.loading = false;
      });
    },
    // 取消按钮
    cancel() {
      this.open = false;
      this.reset();
    },
    // 表单重置
    reset() {
      this.form = {
        id: null,
        title: null,
        longitude: null,
        latitude: null,
        address: null,
        startTime: null,
        endTime: null,
        noticeUrl: null,
        protectUrl: null,
        custodyUrl: null,
        discloseUrl: null,
        checkUrl: null,
        status: 0,
        remark: null,
        createTime: null
      };
      this.resetForm("form");
      this.devicePos = [];
    },
    /** 搜索按钮操作 */
    handleQuery() {
      this.queryParams.pageNum = 1;
      this.getList();
    },
    /** 重置按钮操作 */
    resetQuery() {
      this.resetForm("queryForm");
      this.handleQuery();
    },
    // 多选框选中数据
    handleSelectionChange(selection) {
      this.ids = selection.map(item => item.id);
      this.titles = selection.map(item => item.title);
      this.single = selection.length!==1
      this.multiple = !selection.length
    },
    /** 新增按钮操作 */
    handleAdd() {
      this.reset();
      this.open = true;
      this.title = "添加第三方施工";
    },
    /** 修改按钮操作 */
    handleUpdate(row) {
      this.reset();
      const id = row.id || this.ids
      getBuild(id).then(response => {
        this.form = response.data;
        if(this.form.longitude){
          this.devicePos = [this.form.longitude,this.form.latitude];
        }
        this.getReloadFile(this.form.noticeUrl,"notice");
        this.getReloadFile(this.form.protectUrl,"protectUrl");
        this.getReloadFile(this.form.custodyUrl,"custodyUrl");
        this.getReloadFile(this.form.discloseUrl,"discloseUrl");
        this.getReloadFile(this.form.checkUrl,"checkUrl");
        this.open = true;
        this.title = "修改第三方施工";
      });
    },
    /** 提交按钮 */
    submitForm() {
      this.$refs["form"].validate(valid => {
        if (valid) {
          if (this.form.id != null) {
            updateBuild(this.form).then(response => {
              this.msgSuccess("修改成功");
              this.open = false;
              this.getList();
            });
          } else {
            addBuild(this.form).then(response => {
              this.msgSuccess("新增成功");
              this.open = false;
              this.getList();
            });
          }
        }
      });
    },
    /** 删除按钮操作 */
    handleDelete(row) {
      const ids = row.id || this.ids;
      const titles = row.title || this.titles;
      this.$confirm('是否确认删除工程名称为"' + titles + '"的数据项?', "警告", {
          confirmButtonText: "确定",
          cancelButtonText: "取消",
          type: "warning"
        }).then(function() {
          return delBuild(ids);
        }).then(() => {
          this.getList();
          this.msgSuccess("删除成功");
        }).catch(() => {});
    },
    /** 导出按钮操作 */
    handleExport() {
      const queryParams = this.queryParams;
      this.$confirm('是否确认导出所有第三方施工数据项?', "警告", {
          confirmButtonText: "确定",
          cancelButtonText: "取消",
          type: "warning"
        }).then(() => {
          this.exportLoading = true;
          return exportBuild(queryParams);
        }).then(response => {
          this.download(response.msg);
          this.exportLoading = false;
        }).catch(() => {});
    },
    /**
     * 经纬度坐标方法
     */
    MapdialogFun() {
      this.dialogTableVisibles = true;
    },
    /**
     * 地图关闭方法
     */
    dialogcancelFun() {
      this.dialogTableVisibles = false;
    },
    /**
     * 经纬度 选择
     * @param res
     */
    getPath(res){
      //确认选择经纬度
      this.form.longitude = res[0];
      this.form.latitude = res[1];
      this.devicePos = [res[0],res[1]];
    },
    //详情
    handleDetail(row){
      this.$refs.buildDetail.openDetail(row.id);
    },
    //监护
    handleSupervise(row){
      this.$router.push({path:"/thirdBuildDetail",query:{thirdBuildId:row.id}});
    },
    handleEnd(row){
      this.$confirm('是否确认结束第三方施工名称为"' + row.title + '"的数据项?', "警告", {
        confirmButtonText: "确定",
        cancelButtonText: "取消",
        type: "warning"
      }).then(function() {
        return updateBuild({id:row.id,status:1});
      }).then(() => {
        this.getList();
        this.msgSuccess("关闭成功！");
      }).catch(() => {});
    },
    getReloadFile(file,ref){
      this.$nextTick(() => {
        if(file){
          let temp = 1;
          this.$refs[ref].fileList = file.split(",").map(item => { return{ url:item,uid: new Date().getTime() + temp++ }});
        }
      })
    }
  },
};
</script>
<stlye scoped lang="scss">
  .picture-label{
    font-size: 14px;
    color: rgb(96, 98, 102);
    font-weight: 700;
    margin: 8px 0px 8px 0px;
  }
</stlye>
